{% extends "lfs/base.html" %}
{% load i18n %}
{% load lfs_tags %}

{% block wrapper %}
    <div class="span-5">
        {% block left-slot %}
            <h1>{% trans 'My account' %}</h1>
            <ul>
                <li>
                    <a href="{% url lfs_my_account %}">{% trans 'Overview' %}</a>
                </li>
            </ul>
            <ul>
                <li>
                    <a href="{% url lfs_my_orders %}">{% trans 'Your orders' %}</a>
                </li>
            </ul>
            <ul>
                <li>
                    <a href="{% url lfs_my_password %}">{% trans 'Change password' %}</a>
                </li>
                <li>
                    <a href="{% url lfs_my_email %}">{% trans 'Change e-mail' %}</a>
                </li>
                <li>
                    <a href="{% url lfs_my_addresses %}">{% trans 'Change addresses' %}</a>
                </li>
            </ul>
        {% endblock %}
    </div>
    <div class="span-19 last">
        {% block content %}{% endblock %}
    </div>
{% endblock %}