{% extends "lfs/base.html" %}
{% load i18n %}

{% block section %}{% endblock %}
{% block left-slot-wrapper %}{% endblock %}
{% block right-slot-wrapper %}{% endblock %}

{% block content %}
    <h1>{% trans 'Review' %}</h1>
    <p>{% trans 'You have already rated for this product.' %}</p>    
{% endblock %}
