{% extends "lfs/base.html" %}
{% load i18n %}
{% load lfs_tags %}

{% block title %}{% trans 'Password reset successful' %}{% endblock %}
{% block section %}password-reset{% endblock %}

{% block breadcrumbs %}
    {% breadcrumbs _("Password reset successful") %}
{% endblock %}

{% block content %}
    <h1 class="first-heading">{% trans "Password reset successful" %}</h1>
    <p>{% trans "We've e-mailed you instructions for setting your password to the e-mail address you submitted. You should be receiving it shortly." %}</p>
{% endblock %}
