{% extends "lfs/base.html" %}
{% load i18n %}
{% load lfs_tags %}

{% block title %}
    {% trans 'Cart' %} - {{ block.super }}
{% endblock %}

{% block section %}cart{% endblock %}

{% block breadcrumbs %}
    {% breadcrumbs _('Cart') %}
{% endblock %}

{% block wrapper %}

    <div id="cart-inline">
        {{cart_inline}}
    </div>
{% endblock %}