{% load i18n %}
{% load lfs_tags %}

<div class="shipping-portlet portlet">
    <div class="portlet-header">
        {% trans 'Shipping' %}
    </div>
    
    <div class="portlet-body">
        {% if deliverable %}
            <div>
                {{delivery_time}}
            </div>
        {% else %}
            <div>
                {% trans 'Not deliverable' %}
            </div>        
        {% endif %}        
    </div>
</div>
