{% extends "lfs/base.html" %}
{% load i18n %}
{% load lfs_tags %}

{% block title %}
    {% trans 'Checkout' %} - {{ block.super }}
{% endblock %}

{% block section %}checkout{% endblock %}

{% block breadcrumbs %}
    {% breadcrumbs _("Checkout") %}
{% endblock %}

{% block content %}
    <div>
        {% trans 'There is nothing to checkout' %}
    </div>

    <div class="buttons">
        <a class="button left" href="{{shopping_url}}">{% trans 'Go on shopping' %}</a>
    </div>
    
{% endblock %}
