{% extends "lfs/base.html" %}
{% load i18n %}

{% block title %}{% trans 'Password reset complete' %}{% endblock %}

{% block content %}

    <h1>{% trans 'Password reset complete' %}</h1>
    <p>{% trans "Your password has been set. You may go ahead and log in now." %}</p>    
    <br>
    <p><a href="{{ login_url }}?next={% url lfs_shop_view %}">{% trans 'Login' %}</a></p>

{% endblock %}
