{% load i18n %}
<ul id="menu">
    <li id="c0"><a href='{% url lfs_shop_view %}'>{% trans 'Home' %}</a></li>
    {% for category in categories %}
        <li id="c{{category.id}}"><a {% if category.selected %}class="selected"{% endif %} href='{% url lfs_category category.slug %}'>{{category.name}}</a></li>
    {% endfor %}
</ul>
<br clear="all" />