{% extends "lfs/base.html" %}
{% load i18n %}
{% load lfs_tags %}

{% block title %}{% trans "Password reset" %}{% endblock %}
{% block section %}password-reset{% endblock %}

{% block breadcrumbs %}
    {% breadcrumbs _("Password reset") %}
{% endblock %}

{% block content %}
    <h1 class="first-heading">{% trans "Password reset" %}</h1>
    <p>{% trans "Enter your e-mail address below, and we'll e-mail instructions for setting a new one." %}</p>
    <form action=""
          method="post">
          {% include "lfs/shop/lfs_form.html" %}

        <input type="submit" value="{% trans 'Reset my password' %}" />
    </form>
{% endblock %}
