{% for shipping_method in shipping_methods %}
    <div class="shipping-method container">
        <div class="span-1">
            <input type="radio"
                   name="shipping-method"
                   class="update-checkout"
                   {% ifequal shipping_method.id selected_shipping_method.id  %}checked="checked"{% endifequal %}
                   value="{{shipping_method.id}}" />
        </div>
        <div class="span-3">
            {% if shipping_method.image %}
                <img class="payment-method"
                     src="{{ shipping_method.image.url }}"
                     alt="{{ shipping_method.name }}">
            {% endif %}
        </div>

        <div class="span-6">
            {{ shipping_method.name }}
        </div>
        <div class="span-14 last">
            {{ shipping_method.description|safe }}
        </div>
    </div>
{% endfor %}
