    {% load i18n %}
{% load lfs_tags %}

<div class="shipping-information">
    {% if deliverable %}
        <div class="deliverable">
            {% trans 'Delivery time' %}: {{delivery_time}}
        </div>
    {% else %}
        <div class="not-deliverable">
            {% trans 'Not deliverable' %}
        </div>        
    {% endif %}
</div>