{% load i18n %}
<div class="sorting">
    <form action="{% url lfs_catalog_set_sorting %}"
          method="post">
        <select name="sorting"
                onchange="this.form.submit()">
            <option value="price"
                {% ifequal "price" current %}selected="selected"{% endifequal %}>{% trans 'Price ascending' %}</option>
            <option value="-price"
                {% ifequal "-price" current %}selected="selected"{% endifequal %}>{% trans 'Price descending' %}</option>
            <option value="name"
                {% ifequal "name" current %}selected="selected"{% endifequal %}>{% trans 'Name ascending' %}</option>
            <option value="-name"
                {% ifequal "-name" current %}selected="selected"{% endifequal %}>{% trans 'Name descending' %}</option>
        </select>
        <noscript>
            <input type="submit" value="{% trans 'Go!' %}" />
        </noscript>
    </form>
</div>