body {
    font-size: 70%;
}

#livesearch-result {
    margin-top: 30px;
}

/* Remove image because of the z-index bug */
.cart-portlet .portlet-body {
    padding: 10px ;
}

.cart-portlet .portlet-header img {
    display: none;
}

#id_username,
#id_password_1,
#id_password_2,
#id_password {
    width: 150px;
}