{% load i18n %}
{% load lfs_tags %}

{% if product.get_related_products %}
    <div class="related-products-portlet portlet">
    
        <div class="portlet-header">
            {% trans 'Related Products' %}
        </div>
        
        <div class="portlet-body">
            {% for related_product in product.get_related_products %}
                <div class="portlet-item">
                    <img alt="{{related_product.get_name}}"
                         src="{{related_product.get_image.url_60x60}}" />
                    
                    <div>
                        <a href="{{related_product.get_absolute_url}}">
                            {{related_product.get_name}}
                        </a>
                    </div>
                    <div class="price">
                        {{related_product.get_price|currency}}
                    </div>
                </div>    
            {% endfor %}    
        </div>
    </div>
{% endif %}