{% load i18n %}
<html>
    <head>
        <style type="text/css"></style>
    </head>
    <body>
        <h1>{% trans 'Welcome to' %} {{shop.name}}</h1>
        <p>            
            Lorem ipsum dolor
        </p>
        <p>
            {{user.username}}
        </p>
    </body>
</html>