{% extends "lfs/base.html" %}
{% load i18n %}

{% block title %}{% trans 'Password reset' %}{% endblock %}

{% block content %}

    {% if validlink %}
        <h1>{% trans 'Enter new password' %}</h1>
        <p>{% trans "Please enter your new password twice so we can verify you typed it in correctly." %}</p>
        <form action="" method="post">
            {% include "lfs/shop/lfs_form.html" %}
            <p><input type="submit" value="{% trans 'Change my password' %}" /></p>
        </form>
    {% else %}
        <h1>{% trans 'Password reset unsuccessful' %}</h1>
        <p>{% trans "The password reset link was invalid, possibly because it has already been used.  Please request a new password reset." %}
    {% endif %}

{% endblock %}
