{% extends "lfs/customer/base.html" %}
{% load i18n %}
{% load lfs_tags %}

{% block section %}my-account{% endblock %}

{% block breadcrumbs %}
    {% breadcrumbs _("Your Account") %}
{% endblock %}
