{% load i18n %}
<div class="payment container">
    <h2>{% trans 'Payment' %}</h2>
    {% for payment_method in payment_methods %}
        <div class="payment-method span-24">
            <div class="span-1">
                <input type="radio"
                       name="payment_method"
                       class="update-checkout payment-methods payment-method-type-{{ payment_method.type }}"
                       id="payment-method-{{ payment_method.id }}"
                       {% ifequal payment_method.id selected_payment_method.id  %}checked="checked"{% endifequal %}
                       value="{{payment_method.id}}" />
            </div>

            <div class="span-3">
                {% if payment_method.image %}
                    <img class="payment-method"
                         src="{{ payment_method.image.url }}"
                         alt="{{ payment_method.name }}">
                {% endif %}
            </div>
            <div class="span-6">
                {{ payment_method.name }}
            </div>
            <div class="span-14 last">
                {{ payment_method.description|safe }}
            </div>
        </div>
    {% endfor %}
</div>
