{% load i18n %}
{% load lfs_tags %}

<div class="sorting-portlet portlet">

    <div class="portlet-header">
        {% trans 'Sorting' %}
    </div>
    
    <div class="portlet-body">
        {% include "lfs/catalog/sorting.html" %}
    </div>
    
</div>
