{% extends "lfs/customer/base.html" %}
{% load i18n %}
{% load lfs_tags %}

{% block title %}{% trans 'Password change' %}{% endblock %}

{% block breadcrumbs %}
    {% breadcrumbs _("Password change") %}
{% endblock %}

{% block content %}

    <h1>{% trans 'Password change' %}</h1>

    <p>
        {% trans "Please enter your old password, for security's sake, and then enter your new password twice so we can verify you typed it in correctly." %}
    </p>

    <form action="{% url lfs_my_password %}" 
          method="post">
            <table class="lfs-default">
                <tr>
                    <td class="label">
                        <label for="id_old_password">{% trans 'Old password:' %}</label>
                    </td>
                    <td>
                        {{ form.old_password.errors }}                        
                        {{ form.old_password }}
                    </td>
                </tr>
                <tr>
                    <td class="label">
                        <label for="id_new_password1">{% trans 'New password:' %}</label>
                    </td>
                    <td>
                        {{ form.new_password1.errors }}
                        {{ form.new_password1 }}
                    </td>
                </tr>
                <tr>
                    <td class="label">
                        <label for="id_new_password2">{% trans 'Confirm password:' %}</label>
                    </td>
                    <td>
                        {{ form.new_password2.errors }}
                        {{ form.new_password2 }}
                    </td>
                </tr>
                <tr>
                    <td></td>
                    <td>
                        <input type="submit" value="{% trans 'Change password' %}" />
                    </td>                    
                </tr>
            </table>
        
        </table>  
    </form>

{% endblock %}
